@@ -1,9 +1,9 @@
 from dagster._core.libraries import DagsterLibraryRegistry
 
-from .resources import (
+from dagster_openai.resources import (
     OpenAIResource as OpenAIResource,
     with_usage_metadata as with_usage_metadata,
 )
-from .version import __version__
+from dagster_openai.version import __version__
 
 DagsterLibraryRegistry.register("dagster-openai", __version__)
